@@ -44,9 +44,11 @@
 #define XtNrightAuxBeadColor ((char *) "rightAuxBeadColor")
 #define XtNsecondaryBeadColor ((char *) "secondaryBeadColor")
 #define XtNhighlightBeadColor ((char *) "highlightBeadColor")
+#define XtNcheckerBeadColor ((char *) "checkerBeadColor")
 #define XtNprimaryRailColor ((char *) "primaryRailColor")
 #define XtNsecondaryRailColor ((char *) "secondaryRailColor")
 #define XtNhighlightRailColor ((char *) "highlightRailColor")
+#define XtNlineRailColor ((char *) "lineRailColor")
 #define XtNbumpSound ((char *) "bumpSound")
 #define XtNmoveSound ((char *) "moveSound")
 #define XtNdripSound ((char *) "dripSound")
@@ -336,9 +338,10 @@ typedef struct {
 #define ROMAN 3
 #define RUSSIAN 4
 #define DANISH 5
-#define GENERIC 6
-#define MAX_FORMATS 6
-#define MAX_MODES 7
+#define MEDIEVAL 6
+#define GENERIC 7
+#define MAX_FORMATS 7
+#define MAX_MODES 8
 #define TEACH_STRING0 "Enter calculation X+Y, X-Y, X*Y, X/Y, Xv, or Xu where X positive and result positive."
 #define TEACH_STRING1 "Press enter to go through calculation steps."
 #define ZERO_STRING "0.0"
