@@ -275,6 +275,8 @@ static Expression parseExpression;
 #endif
 
 #ifdef WINVER
+/* Some versions have, some do not, change to 1 if you do not */
+#if 0
 static double
 pow(double x, double y)
 {
@@ -287,6 +289,7 @@ cbrt(double x) /* -inf < x < inf */
 	return ((x < 0.0) ? -pow(-x, 1.0 / 3.0) : pow(x, 1.0 / 3.0));
 }
 #endif
+#endif
 
 static double
 powInt(int base, int y)
@@ -410,7 +413,7 @@ convertFromInteger(char *outputString, int base, int x)
 		placesBase = logInt(number, base);
 		fractDigits -= (placesBase + 1);
 		/* rounder */
-		number += (pow((double) base, -fractDigits) / 2.0);
+		number += (int) (pow((double) base, -fractDigits) / 2.0);
 
 		/* Convert Integer Part */
 		if (number < 1.0) {
@@ -420,9 +423,9 @@ convertFromInteger(char *outputString, int base, int x)
 			placesBase = logInt(number, base);
 			factor = pow((double) base, (double) placesBase);
 			for (; placesBase >= 0; placesBase--) {
-				digit = (int) (number / factor);
+				digit = (short unsigned int) (number / factor);
 				outputString[l++] = DIGIT_TO_CHAR(digit);
-				number -= factor * digit;
+				number -= (int) (factor * digit);
 				factor /= base;
 			}
 		}
@@ -468,7 +471,7 @@ convertFromDouble(char *outputString, int base, double x)
 			placesBase = logInt(number, base);
 			factor = pow((double) base, (double) placesBase);
 			for (; placesBase >= 0; placesBase--) {
-				digit = (int) (number / factor);
+				digit = (short unsigned int) (number / factor);
 				outputString[l++] = DIGIT_TO_CHAR(digit);
 				number -= factor * digit;
 				factor /= base;
@@ -479,7 +482,7 @@ convertFromDouble(char *outputString, int base, double x)
 			outputString[l++] = decimalPoint;
 			for (placesBase = 1; placesBase <= fractDigits;
 					placesBase++) {
-				digit = (int) (number / factor);
+				digit = (short unsigned int) (number / factor);
 				outputString[l++] = DIGIT_TO_CHAR(digit);
 				number -= factor * digit;
 				factor /= base;
@@ -534,7 +537,7 @@ formatToDisplay (char *string, double z, int base)
 	short unsigned int periods = 0;
 
 	convertFromDouble(string, base, z);
-	length = strlen(string);
+	length = (int) strlen(string);
 	while (i <= length) {
 		if (string[i] == '\0' && periods == 0) {
 			j = length;
@@ -1088,7 +1091,7 @@ void
 convertStringToAbacus(AbacusWidget w, char *string, int aux)
 {
 	int decimal = 0;
-	int num, factor, i, sign = 0, len = strlen(string);
+	int num, factor, i, sign = 0, len = (int) strlen(string);
 	AbacusWidget *wap = &w, wa;
 
 	if (aux == 1 && w->abacus.leftAux != NULL)
@@ -1098,8 +1101,10 @@ convertStringToAbacus(AbacusWidget w, char *string, int aux)
 	wa = *wap;
 	if (aux == 0) {
 		clearRails(w);
+#ifndef WINVER
 	} else {
 		clearAuxRails(w, aux);
+#endif
 	}
 	while (string[decimal] != '\0' && string[decimal] != decimalPoint)
 		decimal++;
@@ -1166,14 +1171,14 @@ addBackAnomaly(char * buf, int anomaly, int shift, int base)
 void
 zeroFractionalPart(char * buf)
 {
-		unsigned int i;
+	unsigned int i;
 
-		for (i = 0; i < strlen(buf); i++) {
-			if (buf[i] == '.') {
-				buf[i + 1] = '\0';
-				return;
-			}
+	for (i = 0; i < strlen(buf); i++) {
+		if (buf[i] == '.') {
+			buf[i + 1] = '\0';
+			return;
 		}
+	}
 }
 
 char *strAddChar(char *buf, char c)
