@@ -1,7 +1,7 @@
 /*
  * @(#)AbacusD.c
  *
- * Copyright 1999 - 2012  David A. Bagley, bagleyd@tux.org
+ * Copyright 1999 - 2014  David A. Bagley, bagleyd@tux.org
  *
  * Abacus demo and neat pointers from
  * Copyright 1991 - 1998  Luis Fernandes, elf@ee.ryerson.ca
@@ -395,6 +395,8 @@ postfixType(int mode)
 		return (char *) "ru";
 	case DANISH:
 		return (char *) "ru"; /* dk */
+	case MEDIEVAL:
+		return (char *) ""; /* cn, me, ge, uk */
 	default:
 		return (char *) "";
 	}
