@@ -141,8 +141,7 @@ extern AbacusClassRec abacusClassRec;
 #define DOWN 0
 #define TOP 1
 #define BOTTOM 0
-#define CARRY 2	/* If you have a strange abacus you may have to increase this
-		   also need a space to hold null (not included) */
+#define CARRY 1
 #define SPECIAL_PIECES 2 /* Pieces, PiecePercents */
 
 #define MAX_FORMAT_LENGTH 9
@@ -216,10 +215,9 @@ typedef struct _AbacusPart {
 	int         delay, numSlices, mode, submode, colorScheme, railIndex;
 	int         leftAuxRails, rightAuxRails;
 	int         aux, deck, rail, number;
-	int         pressOffsetX, pressOffsetY;
-	Position    width, middleBarHeight, middleBarPositionY, railWidth;
+	Position    middleBarHeight, middleBarPositionY, railWidth;
 	Point       frameSize, beadSize;
-	Point       pos, delta, offset;
+	Point       pos, totalSize, delta, offset, pressOffset;
 	Boolean     sign, minusSign, romanNumerals, group, decimalComma;
 	Boolean     carryAnomaly, carryAnomalySq;
 	Boolean     mono, reverse, focus, vertical;
@@ -229,9 +227,9 @@ typedef struct _AbacusPart {
 	Boolean     slot, diamond, sound;
 	char       *digits, *mathBuffer;
 	FILE       *fp;
-	GC          frameGC, borderGC, symbolGC, railGC[3], inverseGC;
+	GC          frameGC, borderGC, symbolGC, lineGC, railGC[4], inverseGC;
 	GC          beadShadeGC[MAX_SHADES];
-	Pixmap      bufferBead[3][2][2];
+	Pixmap      bufferBead[4][2][2];
 	TimeVal     oldTime;
 	Boolean     rightToLeftAdd, rightToLeftMult;
 	int         step, carry[2], lower, upper, carryStep;
@@ -256,7 +254,7 @@ typedef struct _AbacusPart {
 	Colormap    colormap;
 	Pixel       foreground, background;
 	Pixel       borderColor, frameColor;
-	Pixel       beadColor[3], railColor[3];
+	Pixel       beadColor[4], railColor[4];
 	Pixel       leftAuxColor, rightAuxColor;
 	XtCallbackList select;
 #endif
