@@ -1,7 +1,7 @@
 /*
  * @(#)AbacusT.c
  *
- * Copyright 2009 - 2012  David A. Bagley, bagleyd@tux.org
+ * Copyright 2009 - 2013  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -349,6 +349,9 @@ static void drawLineText(AbacusWidget w, char* line, int i)
 		w->core.height + w->abacusDemo.fontHeight * i - 1,
 		line, (signed) strlen(line));
 #else
+	if (w == NULL) {
+		return;
+	}
 	drawTeachText(line, i);
 #endif
 #else
@@ -372,7 +375,7 @@ static int getDecimalStringPosition(char * string)
 /* Position of decimal point in int array */
 static int arrayLen(int * array)
 {
-	unsigned int i = 0;
+	int i = 0;
 
 	while (array[i] != -2) {
 		i++;
@@ -383,7 +386,7 @@ static int arrayLen(int * array)
 /* Position of decimal point in int array */
 static int getDecimalArrayPosition(int * array)
 {
-	unsigned int i = 0;
+	int i = 0;
 
 	while (array[i] != -2) {
 		if (array[i] == -1)
@@ -498,7 +501,7 @@ static void  trimStringBuffer(char *string)
 	int last;
 
 	contractStringBuffer(string);
-	last = strlen(string) - 1;
+	last = (int) strlen(string) - 1;
 	if (string[last] == '.')
 		string[last] = '\0';
 }
@@ -525,7 +528,7 @@ static void stripDecimal(char * string) {
 	}
 	if (found == 0)
 		return;
-	length = strlen(string);
+	length = (int) strlen(string);
 	for (i = found; i < length; i++)
 		string[i - found] = string[i];
 	string[length - found] = '\0';
@@ -538,7 +541,7 @@ static void stripStringBuffer(char *string, int len, int steps)
 
 	trimStringBuffer(string);
 	stripDecimal(string);
-	length = strlen(string);
+	length = (int) strlen(string);
 	if (len >= 0) {
 		if (length >= len)
 			string[length - len] = '\0';
@@ -552,7 +555,7 @@ static void stripStringBuffer(char *string, int len, int steps)
 		}
 	}
 #ifdef OLD_DEBUG
-	(void) printf("stripStringBuffer: %s %d\n", string, strlen(string));
+	(void) printf("stripStringBuffer: %s %d\n", string, (int) strlen(string));
 #endif
 }
 #endif
@@ -588,54 +591,54 @@ static void shiftStringBuffer(char * string, int shift)
 	int offset = getDecimalStringPosition(string);
 	int newOffset, i, j, k;
 
-	j = strlen(string);
+	j = (int) strlen(string);
 	if (offset != j)
 		for (i = 0; i < j - offset; i++) {
 			string[offset + i]  = string[offset + i + 1];
 		}
-	j = strlen(string);
+	j = (int) strlen(string);
 	if (offset >= j) {
 		while (j > 1 && string[j - 1] == '0') {
 			string[j - 1] = string[j];
 		}
 	}
 	if (offset == 1 && string[0] == '0') {
-		while (strlen(string) > 1 &&
+		while (((int) strlen(string)) > 1 &&
 				string[0] == '0') {
-			j = strlen(string);
+			j = (int) strlen(string);
 			for (i = 1; i <= j; i++) {
 				string[i - 1] = string[i];
 			}
 			offset--;
 		}
 	}
-	if (string[0] == '0' && strlen(string) == 1) {
+	if (string[0] == '0' && ((int) strlen(string)) == 1) {
 		return;
 	}
 	newOffset = offset + shift;
 	if (newOffset <= 0) {
 		for (i = 0; i < -newOffset; i++) {
-			j = strlen(string);
+			j = (int) strlen(string);
 			for (k = j; k >= 0; k--) {
 				string[k + 1] = string[k];
 			}
 			string[0] = '0';
 		}
-		j = strlen(string);
+		j = (int) strlen(string);
 		for (i = j; i >= 0; i--) {
 			string[i + 2] = string[i];
 		}
 		string[0] = '0';
 		string[1] = '.';
 	} else if (newOffset >= (int) strlen(string)) {
-		newOffset -= strlen(string);
+		newOffset -= (int) strlen(string);
 		for (i = 0; i < newOffset; i++) {
-			j = strlen(string);
+			j = (int) strlen(string);
 			string[j] = '0';
 			string[j + 1] = '\0';
 		}
 	} else {
-		for (i = strlen(string); i >= newOffset; i--) {
+		for (i = (int) strlen(string); i >= newOffset; i--) {
 			string[i + 1] = string[i];
 		}
 		string[newOffset] = '.';
@@ -830,7 +833,7 @@ static int nextCharPosition(AbacusWidget w, int step, int carryStep, int aux,
 	AbacusWidget *wap = &w, wa;
 
 	if ((int) strlen(string) == getDecimalStringPosition(string))
-		count = strlen(string); /* no decimal point */
+		count = (int) strlen(string); /* no decimal point */
 	if (aux == 1 && w->abacus.leftAux != NULL)
 		wap = (AbacusWidget *) w->abacus.leftAux;
 	else if (aux == 2 && w->abacus.rightAux != NULL)
@@ -905,7 +908,7 @@ static int placeGroup(int *intGroup)
 static int andAbove(char * string, int place, int base)
 {
 	int i, value = 0, factor = 1, pos;
-	int runover = decimalOffsetString(string, place) - strlen(string);
+	int runover = decimalOffsetString(string, place) - (int) strlen(string);
 	int newPlace = place;
 
 	if (runover > 0)
@@ -931,7 +934,7 @@ static int andAbove(char * string, int place, int base)
 static int andAbovePlaces(char * string, int place)
 {
 	int i, j, pos = 0;
-	int runover = decimalOffsetString(string, place) - strlen(string);
+	int runover = decimalOffsetString(string, place) - (int) strlen(string);
 	int newPlace = place;
 	Boolean decimalValue = False;
 	Boolean intValue = False;
@@ -945,7 +948,7 @@ static int andAbovePlaces(char * string, int place)
 		}
 	}
 	/* Handle numbers < 1 */
-	for (j = 0; j < strlen(string); j++) {
+	for (j = 0; j < (int) strlen(string); j++) {
 		if (string[j] == '0') {
 			if (decimalValue)
 				i--;
@@ -1088,7 +1091,7 @@ static int multDivSteps(AbacusWidget w, char * aString, char * bString)
 {
 	/* decimal included */
 	return divSteps(w, aString, bString, w->abacus.decimalPosition) *
-		(strlen(bString) - 1);
+		((int) strlen(bString) - 1);
 }
 
 /* Number of subtraction steps for each multiplication in division */
@@ -1123,7 +1126,7 @@ static double headDivisor(AbacusWidget w, char * string)
 static void rootGroup(AbacusWidget w, char* string, int root, int** group)
 {
 	int decimal = getDecimalStringPosition(string);
-	int length = strlen(string);
+	int length = (int) strlen(string);
 	int nIntegral = decimal;
 	int nDecimal = length - decimal - 1;
 	int i, j, k, b, n;
@@ -1135,7 +1138,7 @@ static void rootGroup(AbacusWidget w, char* string, int root, int** group)
 	n = nIntegral + nDecimal + 1;
 	if (*group != NULL)
 		free(*group);
-	*group = (int *) malloc(sizeof (int) * n + 1);
+	*group = (int *) malloc(sizeof (int) * (size_t) (n + 1));
 	for (i = 0; i < nIntegral; i++) {
 		k = i * root + (decimal + root - 1) % root;
 		(*group)[i] = 0;
@@ -1604,7 +1607,7 @@ static Boolean nextPositionDivision(AbacusWidget w,
 		w->abacus.bString);
 	int topFactor = w->abacus.decks[TOP].factor;
 	int bottomNumber = w->abacus.decks[BOTTOM].number;
-	int bCount = strlen(w->abacus.bString) - 1;
+	int bCount = (int) strlen(w->abacus.bString) - 1;
 	Boolean rightToLeft = w->abacus.rightToLeftAdd;
 	int bOffset, rOffset;
 	int aPlace, bPlace, rPlace, rDigit;
@@ -1904,7 +1907,7 @@ static Boolean nextPositionPOField(AbacusWidget w,
 }
 
 /* A little tricky as this is reentrant */
-void teachStepRoot(AbacusWidget w)
+static void teachStepRoot(AbacusWidget w)
 {
 	char buffer2[120] = "";
 	char buffer3[120] = "";
@@ -2377,9 +2380,9 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 		if (w->abacus.op == '+' || w->abacus.op == '-') {
 			convertStringToAbacus(w, w->abacus.aString, aux);
 			if (w->abacus.leftAux != NULL)
-				convertStringToAbacus(w, (char *) "0.0", 1);
+				convertStringToAbacus(w, (char *) ZERO_STRING, 1);
 			if (w->abacus.rightAux != NULL)
-				convertStringToAbacus(w, (char *) "0.0", 2);
+				convertStringToAbacus(w, (char *) ZERO_STRING, 2);
 			a = convertToDecimal(base, w->abacus.aString);
 			b = convertToDecimal(base, w->abacus.bString);
 			if (w->abacus.op == '-' && b > a) {
@@ -2408,7 +2411,7 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 		} else if (w->abacus.op == '*') {
 			if (strlen(w->abacus.aString) == 0)
 				return;
-			convertStringToAbacus(w, (char *) "0.0", 0);
+			convertStringToAbacus(w, (char *) ZERO_STRING, 0);
 			if (w->abacus.leftAux != NULL)
 				convertStringToAbacus(w, w->abacus.aString, 1);
 			a = convertToDecimal(base, w->abacus.aString);
@@ -2443,7 +2446,7 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 		} else if (w->abacus.op == '/') {
 			if (strlen(w->abacus.aString) == 0)
 				return;
-			convertStringToAbacus(w, (char *) "0.0", 2);
+			convertStringToAbacus(w, (char *) ZERO_STRING, 2);
 			convertStringToAbacus(w, w->abacus.aString, 0);
 			a = convertToDecimal(base, w->abacus.aString);
 			if (w->abacus.rightAux != NULL)
@@ -2495,9 +2498,9 @@ void teachStep(AbacusWidget w, char * buffer, int aux)
 			stringGroup(w->abacus.intGroup, group, w->abacus.op);
 			convertStringToAbacus(w, w->abacus.aString, aux);
 			if (w->abacus.leftAux != NULL)
-				convertStringToAbacus(w, (char *) "0.0", 1);
+				convertStringToAbacus(w, (char *) ZERO_STRING, 1);
 			if (w->abacus.rightAux != NULL)
-				convertStringToAbacus(w, (char *) "0.0", 2);
+				convertStringToAbacus(w, (char *) ZERO_STRING, 2);
 			a = convertToDecimal(base, w->abacus.aString);
 			(void) sprintf(buffer1, "%s root of %s, grouping digits yields (%s)",
 				((w->abacus.op == 'v') ? "Square" : "Cube"),
